package Perinci::Examples::Bin::Any::SahSchemas;

our $DATE = '2018-01-15'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Example CLI scripts to test various Sah schemas

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Examples::Bin::Any::SahSchemas - Example CLI scripts to test various Sah schemas

=head1 VERSION

This document describes version 0.002 of Perinci::Examples::Bin::Any::SahSchemas (from Perl distribution Perinci-Examples-Bin-Any-SahSchemas), released on 2018-01-15.

=head1 DESCRIPTION

This distribution contains the following scripts:

=over

=item * L<peri-eg-schema-date>

=item * L<peri-eg-schema-dirname>

=item * L<peri-eg-schema-filename>

=item * L<peri-eg-schema-pathname>

=item * L<peri-eg-schema-perl-distname>

=item * L<peri-eg-schema-perl-modname>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin-Any-SahSchemas>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples-Bin-Any-SahSchemas>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Any-SahSchemas>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

Related C<Sah::Schema::*> modules

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
